/**
 * detect-event-listener v1.0.3
 * Copyright (c) 2020 Maciej Krawczyk
 * License: MIT
 */
/**
 * Detects support for addEventListener, including its third options parameter and passive events.
 *
 * Inspired by
 * https://developer.mozilla.org/en-US/docs/Web/API/EventTarget/addEventListener#Safely_detecting_option_support
 */
function detectEventListener() {
    const result = {
        supportsEventListener: false,
        supportsOptions: false,
        supportsPassive: false,
        supportsOnce: false,
    };
    if (typeof window !== 'undefined' && typeof window.addEventListener === 'function') {
        result.supportsEventListener = true;
    }
    else {
        return result;
    }
    // Detect if options parameter is supported, by testing for capture property - which was in the
    // initial spec for options parameter.
    try {
        const options = {
            // This getter will be called when capture property is read
            get capture() {
                result.supportsOptions = true;
                return false;
            },
        };
        window.addEventListener('test', null, options);
        window.removeEventListener('test', null, options);
    }
    catch (err) {
        //
    }
    if (!result.supportsOptions) {
        return result;
    }
    try {
        const options = {
            get passive() {
                result.supportsPassive = true;
                return false;
            },
        };
        window.addEventListener('test', null, options);
        window.removeEventListener('test', null, options);
    }
    catch (err) {
        //
    }
    try {
        const options = {
            get once() {
                result.supportsOnce = true;
                return false;
            },
        };
        window.addEventListener('test', null, options);
        window.removeEventListener('test', null, options);
    }
    catch (err) {
        //
    }
    return result;
}

export { detectEventListener };
